Title: [191155] trunk/Source/WebCore
Revision
191155
Author
hy...@apple.com
Date
2015-10-15 17:18:35 -0700 (Thu, 15 Oct 2015)

Log Message

Patch parseKeywordValue to accept "unset" so that it goes down the faster parsing path.
https://bugs.webkit.org/show_bug.cgi?id=150213

Reviewed by Dean Jackson.

No new tests as correctness doesn't change (just speed).

* css/CSSParser.cpp:
(WebCore::parseKeywordValue):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (191154 => 191155)


--- trunk/Source/WebCore/ChangeLog	2015-10-16 00:13:36 UTC (rev 191154)
+++ trunk/Source/WebCore/ChangeLog	2015-10-16 00:18:35 UTC (rev 191155)
@@ -1,5 +1,17 @@
 2015-10-15  David Hyatt  <hy...@apple.com>
 
+        Patch parseKeywordValue to accept "unset" so that it goes down the faster parsing path.
+        https://bugs.webkit.org/show_bug.cgi?id=150213
+
+        Reviewed by Dean Jackson.
+
+        No new tests as correctness doesn't change (just speed).
+
+        * css/CSSParser.cpp:
+        (WebCore::parseKeywordValue):
+
+2015-10-15  David Hyatt  <hy...@apple.com>
+
         Add support for the CSS 'unset' keyword.
         https://bugs.webkit.org/show_bug.cgi?id=148614
 

Modified: trunk/Source/WebCore/css/CSSParser.cpp (191154 => 191155)


--- trunk/Source/WebCore/css/CSSParser.cpp	2015-10-16 00:13:36 UTC (rev 191154)
+++ trunk/Source/WebCore/css/CSSParser.cpp	2015-10-16 00:18:35 UTC (rev 191155)
@@ -1197,10 +1197,10 @@
     if (!isKeywordPropertyID(propertyId)) {
         // All properties accept the values of "initial" and "inherit".
         String lowerCaseString = string.lower();
-        if (lowerCaseString != "initial" && lowerCaseString != "inherit")
+        if (lowerCaseString != "initial" && lowerCaseString != "inherit" && lowerCaseString != "unset")
             return CSSParser::ParseResult::Error;
 
         // Parse initial/inherit shorthands using the CSSParser.
         if (shorthandForProperty(propertyId).length())
             return CSSParser::ParseResult::Error;
     }
@@ -1197,10 +1197,10 @@
             return CSSParser::ParseResult::Error;
 
-        // Parse initial/inherit shorthands using the CSSParser.
+        // Parse initial/inherit/unset shorthands using the CSSParser.
         if (shorthandForProperty(propertyId).length())
             return CSSParser::ParseResult::Error;
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to